#!/usr/bin/env python3
from .fast_eval.py import main
main()
